@@ -3,7 +3,7 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.11   update date: 2024-12-11
+# Version : 1.4.12   update date: 2024-12-11
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -152,6 +152,12 @@ if [[ x"$DBS1GB" = xy || x"$DBS1GB" = xY ]]; then
   TEMPSIZE=1024000
   DATASIZE=1024000
 fi
+METADATASIZE=$(expr ${SBSPACESIZE} / 5)
+if [ ${METADATASIZE:-0} -eq 0 ]; then
+  METADATAINFO=""
+else
+  METADATAINFO=" -Mo 0 -Ms ${METADATASIZE}"
+fi
 
 if [ ${NUMCPU:-0} -eq 0 ]; then
   echo "GET cpu information error."
@@ -286,7 +292,7 @@ cat >> $USER_HOME/.bash_profile <<EOF 2>/dev/null
 export ${USER_UPPER}DIR=${INSTALL_DIR}
 export ${USER_UPPER}SERVER=${GBASESERVER}
 export ONCONFIG=onconfig.\$${USER_UPPER}SERVER
-export PATH=\$${USER_UPPER}DIR/bin:\$${USER_UPPER}DIR/sbin:\$${USER_UPPER}DIR/sbin:\${PATH}
+export PATH=\$${USER_UPPER}DIR/bin:\$${USER_UPPER}DIR/sbin:\${PATH}
 export ${USER_UPPER}SQLHOSTS=${INSTALL_DIR}/etc/sqlhosts
 export SERVER_LOCALE=${GBASELOCALE}
 export DB_LOCALE=${GBASELOCALE}
@@ -295,6 +301,7 @@ export GL_USEGLU=1
 # export NODEFDAC=yes
 export DBDATE="Y4MD-"
 export DBACCESS_SHOW_TIME=1
+export IFX_NO_TIMELIMIT_WARNING=y
 EOF
 chown ${USER_NAME}:${USER_NAME} $USER_HOME/.bash_profile
 chmod 0644 $USER_HOME/.bash_profile
@@ -410,7 +417,7 @@ _loginfo "Creating dbspace llogdbs."
 su - ${USER_NAME} -c "onspaces -c -d llogdbs -p $DATADIR/llogchk -o 0 -s $LLOGSIZE >/dev/null 2>&1"
 
 _loginfo "Creating smart blob space sbspace01"
-su - ${USER_NAME} -c "onspaces -c -S sbspace01 -p $DATADIR/sbspace01 -o 0 -s $SBSPACESIZE >/dev/null 2>&1"
+su - ${USER_NAME} -c "onspaces -c -S sbspace01 -p $DATADIR/sbspace01 -o 0 -s $SBSPACESIZE $METADATAINFO >/dev/null 2>&1"
 
 _loginfo "Creating dbspace tempdbs01"
 su - ${USER_NAME} -c "onspaces -c -d tempdbs01 -p $DATADIR/tempchk01 -t -o 0 -s $TEMPSIZE $PAGESIZE >/dev/null 2>&1"
