@@ -3,7 +3,7 @@
 # Filename: CleanAll.sh
 # Function: Clean GBase 8s Auto Install.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.9   update date: 2024-06-11
+# Version : 1.4.10   update date: 2024-06-28
 ##################################################################
 ##### Define Parameter
 ##### Get Parameter
@@ -45,6 +45,16 @@ su - ${USER_NAME} -c "onclean -ky" 2>/dev/null
 ps -ef | awk '/oninit/ && $3==1{print "kill -9 "$2}' | sh 2>/dev/null
 userdel -rf ${USER_NAME} 2>/dev/null
 groupdel ${USER_NAME} 2>/dev/null
+id dbaao 2>/dev/null
+if [ $? -eq 0 ]; then
+  userdel -rf dbaao 2>/dev/null
+  groupdel dbaao 2>/dev/null
+fi
+id dbsso 2>/dev/null
+if [ $? -eq 0 ]; then
+  userdel -rf dbsso 2>/dev/null
+  groupdel dbsso 2>/dev/null
+fi
 
 if [ -d "$INSTALL_DIR" -a ! x$INSTALL_DIR = x/ ]; then
   read -p "Drop directory [$INSTALL_DIR]? [Y/N] " ISDROP 
